import java.io.*;
/**
* Simple Parser driver.
*/
public class ParseTest {
	/** 
	* Test harness for the Parser class.pathname to parse.  Command switches
	* must precede the filepath.
	* <ul>
	* <li><b>-methods, -nomethods</b> - enable/disable tracing of method entry/exit</li>
	* <li><b>-symbols, -nosymbols</b> - enable/disable tracing of Symbols as they are defined</li>
	* <li><b><i>src</i></b> - pathname of the file to parse, including the extension (eg, a.fm).  
  * If not specified, then the program tries to parse "fm/hello.fm".</li>
  * <li><b><i>dst</i></b> - pathname of the file to write to, including the extension (eg, a.txt).
  * If not specified, then uses src file path with .txt as the extension in place of the original extension.</li>
	* </ul>
	* @param arg  the String array of command switches and arguments
	* @throws IOException thrown if any IO errors occur during processing
	*/
	public static void main(String[] arg) throws IOException {
		boolean methods = true;
		boolean symbols = false;
		String src = "fm/hello.fm";
    String dst = "fm/hello.txt";
		int argN = 0;
		// check for -switches
		while (argN < arg.length) {
			if (arg[argN].charAt(0) != '-') break;
			String tag = arg[argN];
			if (tag.equals("-methods")) methods=true;
			else if (tag.equals("-nomethods")) methods=false;
			else if (tag.equals("-symbols")) symbols = true;
			else if (tag.equals("-nosymbols")) symbols = false;
			else System.out.println("unrecognized switch: "+tag);
			argN++;
		}
		// check for input file pathname
		if (argN < arg.length) {
			src = arg[argN++];
		}
    
    // check for output file pathname
    if (argN < arg.length) {
      dst = arg[argN++];
    } else {
      int dot = src.lastIndexOf('.');
      dst = (dot > -1) ? src.substring(0,dot) : src;
      dst = dst + ".txt";

    }
		CompilerIO io = new CompilerIO(src,dst,null);
		io.setEchoing(true);
		io.setEchoPrefix("% ");
		SymbolTable sym = new SymbolTable(2);
		Scanner lex = new Scanner(io,sym);
		Parser p = new Parser(io,sym,lex);
		p.setShowMethods(methods);
		p.setShowSymbols(symbols);
		if (p.parse()) {
			System.out.println("Parsed "+src+" successfully.");
		} else {
			System.out.println("Parse errors in "+src);
		}
		io.closeAll();
	}
}

